@@ -14,7 +14,9 @@ if not JIRA_TOKEN or not JIRA_USERNAME:
     sys.exit(1)
 
 
-def add_comment(server, task_id, comment):
+def add_comment(server, task_id, comment, comment_file):
+    if comment_file:
+        comment = comment_file.read()
     jira = JIRA(
         server=server,
         basic_auth=(JIRA_USERNAME, JIRA_TOKEN))
@@ -25,10 +27,11 @@ def main():
     parser = argparse.ArgumentParser()
     parser.add_argument('--server', required=True)
     parser.add_argument('--task-id', required=True)
-    parser.add_argument('--comment', required=True)
+    parser.add_argument('--comment')
+    parser.add_argument('--comment-file', type=argparse.FileType('r'))
     args = parser.parse_args()
     try:
-        add_comment(args.server, args.task_id, args.comment)
+        add_comment(args.server, args.task_id, args.comment, args.comment_file)
     except Exception as e:
         logger.error("Unable to comment jira task")
         logger.error(e)
